(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     53496,       1474]
NotebookOptionsPosition[     51450,       1402]
NotebookOutlinePosition[     52217,       1428]
CellTagsIndexPosition[     52174,       1425]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

M. Torrilhon, Einstein Convention in Cartesian Coordinates with Mathematica
(2012)\
\>", "Text",
 CellChangeTimes->{
  3.536079298801049*^9, {3.5361767002661014`*^9, 3.536176714992527*^9}, {
   3.5361774881766853`*^9, 3.536177490360689*^9}, {3.5371183779972205`*^9, 
   3.537118409088075*^9}, {3.5371203495784836`*^9, 3.537120363883709*^9}, {
   3.544510109379571*^9, 3.544510129770348*^9}, {3.6788626619207287`*^9, 
   3.6788626623683577`*^9}}],

Cell[CellGroupData[{

Cell["Index Notation and Summation Convention", "Section",
 CellChangeTimes->{{3.5360792581005783`*^9, 3.5360792676321945`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "ii", ",", "jj", ",", "ex", ",", "ex0", ",", "ex1", ",", "ex2", ",", 
    "idx1", ",", "idx2", ",", "rule", ",", "\[Delta]", ",", "pos", ",", "idx",
     ",", " ", "double", ",", "sidx", ",", "dummy", ",", "xx", ",", 
    "\[Delta]$", ",", "\[Delta]"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"StandardizeIdx", "[", 
    RowBox[{"ex_", ",", "flag_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ex0", ",", "ex1", ",", "pos", ",", "idx", ",", "double", ",", "dummy", 
       ",", 
       RowBox[{"sidx", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "s0", ",", "s1", ",", "s2", ",", "s3", ",", "s4", ",", "s5", ",", 
            "s6", ",", "s7", ",", "s8", ",", "s9"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "p0", ",", "p1", ",", "p2", ",", "p3", ",", "p4", ",", "p5", ",", 
            "p6", ",", "p7", ",", "p8", ",", "p9"}], "}"}]}], "}"}]}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ex0", "=", 
       RowBox[{"dummy", " ", "ex"}]}], ";", "    ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"pos", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", "List"}], "]"}], ",", "None", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "     ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "pos", " ", "identifies", " ", "all", " ", "lists", " ", "of", " ", 
         "indices", " ", "in", " ", "the", " ", "expression"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"idx", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"idx", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"idx", ",", 
            RowBox[{"Extract", "[", 
             RowBox[{"ex0", ",", 
              RowBox[{
              "pos", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], "\[Equal]", "3"}], ",", 
           RowBox[{"idx", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"idx", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"ex0", ",", 
                RowBox[{
                "pos", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "idx", " ", "contains", " ", "all", " ", "the", " ", "indices", " ", 
         "in", " ", "the", " ", "expression"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
         "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], ",", 
         
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "ex0", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"double", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Count", "[", 
             RowBox[{"idx", ",", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}], "\[Equal]", "2"}], "&&", 
           RowBox[{"!", 
            RowBox[{"MemberQ", "[", 
             RowBox[{"double", ",", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}]}], ",", 
          RowBox[{"double", "=", 
           RowBox[{"Join", "[", 
            RowBox[{"double", ",", 
             RowBox[{"{", 
              RowBox[{
              "idx", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
              "}"}]}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "double", " ", "contains", " ", "all", " ", "the", " ", "double", " ",
          "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"ex1", "=", 
         RowBox[{"ReplacePart", "[", 
          RowBox[{"ex1", ",", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"ex1", ",", 
              RowBox[{
              "double", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}], "\[Rule]", 
            RowBox[{"sidx", "\[LeftDoubleBracket]", 
             RowBox[{"flag", ",", "ii"}], "\[RightDoubleBracket]"}]}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "double", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"ex1", "=", 
         RowBox[{"ReplacePart", "[", 
          RowBox[{"ex1", ",", 
           RowBox[{
            RowBox[{
            "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "\[Rule]", 
            RowBox[{"Sort", "[", 
             RowBox[{"Extract", "[", 
              RowBox[{"ex1", ",", 
               RowBox[{
               "pos", "\[LeftDoubleBracket]", "ii", 
                "\[RightDoubleBracket]"}]}], "]"}], "]"}]}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Apply", "[", 
        RowBox[{"Times", ",", "ex1"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"dummy", "\[Rule]", "1"}], "}"}]}]}]}], "\[IndentingNewLine]",
     "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Einstein1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ex0", ",", "ex1", ",", "ex2", ",", "idx1", ",", "idx2", ",", "rule", 
       ",", "dummy"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"ex", "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", "ex", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ex0", "=", 
       RowBox[{"dummy", " ", "ex"}]}], ";", "  ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex0", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Head", "[", 
               RowBox[{
               "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}],
                "]"}], "===", "Power"}], "&&", 
             RowBox[{
              RowBox[{"Length", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{
                 "ex0", "\[LeftDoubleBracket]", "ii", 
                  "\[RightDoubleBracket]"}], ",", "List"}], "]"}], "]"}], ">",
               "0"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"ex0", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"{", 
               RowBox[{"jj", ",", "1", ",", 
                RowBox[{"ex0", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], 
               "}"}]}], "]"}], ",", 
            RowBox[{
            "ex0", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}]}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"ii", ",", "1", ",", 
            RowBox[{"Length", "[", "ex0", "]"}]}], "}"}]}], "]"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "makes", " ", "sure", " ", "expression", " ", "is", " ", "a", " ", 
         "product"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"ex1", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"ex0", ",", 
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", 
           RowBox[{"\[Delta]", "[", "_", "]"}]}], "]"}]}], "]"}]}], ";", 
      "   ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "list", " ", "all", " ", "\[Delta]", " ", "expressions", " ", "and", 
         " ", "corresponding", " ", "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"idx1", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"ex1", ",", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Drop", "[", 
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{"ex1", ",", "List"}], "]"}], ",", "None", ",", 
             RowBox[{"-", "1"}]}], "]"}], ",", "1"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"ex2", "=", 
       RowBox[{"Delete", "[", 
        RowBox[{"ex0", ",", 
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", 
           RowBox[{"\[Delta]", "[", "_", "]"}]}], "]"}]}], "]"}]}], ";", 
      "    ", 
      RowBox[{"(*", 
       StyleBox[
        RowBox[{
        "list", " ", "expressions", " ", "without", " ", "\[Delta]", " ", 
         "and", " ", "corresponding", " ", "indices"}],
        FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"idx2", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Extract", "[", 
         RowBox[{"ex2", ",", 
          RowBox[{"Drop", "[", 
           RowBox[{
            RowBox[{"Drop", "[", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"ex2", ",", "List"}], "]"}], ",", "None", ",", 
              RowBox[{"-", "1"}]}], "]"}], ",", "1"}], "]"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"rule", "=", 
          RowBox[{"{", "}"}]}], ";", "     ", 
         RowBox[{"(*", 
          StyleBox[
           RowBox[{
           "extract", " ", "of", " ", "index", " ", "replacement", " ", 
            "rule"}],
           FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Count", "[", 
             RowBox[{
              RowBox[{"Join", "[", 
               RowBox[{"idx2", ",", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Delete", "[", 
                  RowBox[{"idx1", ",", 
                   RowBox[{"{", "ii", "}"}]}], "]"}], "]"}]}], "]"}], ",", 
              RowBox[{"idx1", "\[LeftDoubleBracket]", 
               RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
            "\[Equal]", "1"}], ",", 
           RowBox[{
            RowBox[{"rule", "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"idx1", "\[LeftDoubleBracket]", 
                RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], "->", 
               RowBox[{"idx1", "\[LeftDoubleBracket]", 
                RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], 
              "}"}]}], ";"}], "\[IndentingNewLine]", ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Count", "[", 
               RowBox[{
                RowBox[{"Join", "[", 
                 RowBox[{"idx2", ",", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"Delete", "[", 
                    RowBox[{"idx1", ",", 
                    RowBox[{"{", "ii", "}"}]}], "]"}], "]"}]}], "]"}], ",", 
                RowBox[{"idx1", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], "]"}],
               "\[Equal]", "1"}], ",", 
             RowBox[{
              RowBox[{"rule", "=", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"idx1", "\[LeftDoubleBracket]", 
                  RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}], "->", 
                 RowBox[{"idx1", "\[LeftDoubleBracket]", 
                  RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                "}"}]}], ";"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "rule", "]"}], "\[Equal]", "1"}], ",", 
           "     ", 
           RowBox[{"(*", 
            StyleBox[
             RowBox[{"apply", " ", "index", " ", "replacement", " ", "rule"}],
             
             FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ex1", "=", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"ex1", ",", 
                RowBox[{
                 RowBox[{"{", "ii", "}"}], "\[Rule]", "1"}]}], "]"}], "/.", 
              "rule"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"ex2", "=", 
             RowBox[{"ex2", "/.", "rule"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"idx1", "=", 
             RowBox[{
              RowBox[{"ReplacePart", "[", 
               RowBox[{"idx1", ",", 
                RowBox[{
                 RowBox[{"{", "ii", "}"}], "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}], "}"}]}]}], "]"}], "/.", "rule"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"idx2", "=", 
             RowBox[{"idx2", "/.", "rule"}]}], ";"}]}], "\[IndentingNewLine]",
           "]"}], ";"}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx1", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{
            "idx1", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
            "]"}], ">", "0"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"idx1", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "1"}], "\[RightDoubleBracket]"}], "\[Equal]", 
             RowBox[{"idx1", "\[LeftDoubleBracket]", 
              RowBox[{"ii", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
            RowBox[{"ex1", "=", 
             RowBox[{"ReplacePart", "[", 
              RowBox[{"ex1", ",", 
               RowBox[{
                RowBox[{"{", "ii", "}"}], "\[Rule]", "3"}]}], "]"}]}]}], 
           "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "idx1", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"StandardizeIdx", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Apply", "[", 
          RowBox[{"Times", ",", 
           RowBox[{"Join", "[", 
            RowBox[{"ex1", ",", "ex2"}], "]"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{"dummy", "\[Rule]", "1"}], "}"}]}], ",", "1"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Einstein", "[", "ex_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", "ex", "]"}], "===", " ", "Plus"}], ",", 
     RowBox[{"Apply", "[", 
      RowBox[{"Plus", ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Einstein1", "[", 
          RowBox[{
          "ex", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "[", "ex", "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"Einstein1", "[", "ex", "]"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]$", "[", 
    RowBox[{"ii_", ",", "jj_"}], "]"}], "=", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"ii", ",", "jj"}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DeltaTensor", "[", "idx_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "xx", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OddQ", "[", 
          RowBox[{"Length", "[", "idx", "]"}], "]"}], ",", 
         RowBox[{"Return", "[", "0", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xx", "=", 
        RowBox[{"Permutations", "[", "idx", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Expand", "[", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           RowBox[{"Length", "[", "idx", "]"}], "!"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Product", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"KroneckerDelta", "[", 
               RowBox[{
                RowBox[{"xx", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", "jj"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"xx", "\[LeftDoubleBracket]", 
                 RowBox[{"ii", ",", 
                  RowBox[{"jj", "+", "1"}]}], "\[RightDoubleBracket]"}]}], 
               "]"}], "/.", 
              RowBox[{"{", 
               RowBox[{"KroneckerDelta", "\[Rule]", "\[Delta]$"}], "}"}]}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"jj", ",", "1", ",", 
               RowBox[{"Length", "[", "idx", "]"}], ",", "2"}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"ii", ",", "1", ",", 
             RowBox[{
              RowBox[{"Length", "[", "idx", "]"}], "!"}]}], "}"}]}], "]"}]}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sym1", "[", "ex_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ex0", "=", "ex"}], ",", "pos", ",", "idx", ",", "perm", ",", 
       "double", ",", "tmp"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pos", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"ex0", ",", "List"}], "]"}], ",", "None", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "  ", "\[IndentingNewLine]", 
      RowBox[{"idx", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"idx", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"idx", ",", 
            RowBox[{"Extract", "[", 
             RowBox[{"ex0", ",", 
              RowBox[{
              "pos", "\[LeftDoubleBracket]", "ii", 
               "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], 
             "]"}], "\[Equal]", "3"}], ",", 
           RowBox[{"idx", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"idx", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"ex0", ",", 
                RowBox[{
                "pos", "\[LeftDoubleBracket]", "ii", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}]}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "pos", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"double", "=", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Tally", "[", "idx", "]"}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ">",
              "1"}], ")"}], "&"}]}], "]"}], "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"idx", "=", 
         RowBox[{"Delete", "[", 
          RowBox[{"idx", ",", 
           RowBox[{"Position", "[", 
            RowBox[{"idx", ",", 
             RowBox[{
             "double", "\[LeftDoubleBracket]", "kk", 
              "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"kk", ",", "1", ",", 
          RowBox[{"Length", "[", "double", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"perm", "=", 
       RowBox[{"Permutations", "[", "idx", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"ex0", "/.", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Thread", "[", 
           RowBox[{"idx", "\[Rule]", 
            RowBox[{
            "perm", "\[LeftDoubleBracket]", "kk", "\[RightDoubleBracket]"}]}],
            "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"kk", ",", "1", ",", 
            RowBox[{
             RowBox[{"Length", "[", "idx", "]"}], "!"}]}], "}"}]}], "]"}]}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"StandardizeIdx", "[", 
          RowBox[{
           RowBox[{
           "tmp", "\[LeftDoubleBracket]", "kk", "\[RightDoubleBracket]"}], 
           ",", "2"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"kk", ",", "1", ",", 
           RowBox[{"Length", "[", "tmp", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"Length", "[", "perm", "]"}]], "tmp"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sym", "[", "ex_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "ex", "]"}], "===", " ", "Plus"}], ",", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"sym1", "[", 
         RowBox[{
         "ex", "\[LeftDoubleBracket]", "ii", "\[RightDoubleBracket]"}], "]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "1", ",", 
          RowBox[{"Length", "[", "ex", "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
    
    RowBox[{"sym1", "[", "ex", "]"}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.535821055158787*^9, 3.535821066078806*^9}, {
   3.535821166901783*^9, 3.5358212958048096`*^9}, {3.5358214123838143`*^9, 
   3.5358214147862186`*^9}, {3.5358215618008766`*^9, 3.535821604123751*^9}, {
   3.535821698332317*^9, 3.5358217011715217`*^9}, {3.5358217447579985`*^9, 
   3.5358217566140194`*^9}, {3.535822680152241*^9, 3.535822696126669*^9}, {
   3.5358228323617086`*^9, 3.5358228417061253`*^9}, {3.5358231551106753`*^9, 
   3.535823169774701*^9}, {3.5358232120663757`*^9, 3.535823265168869*^9}, {
   3.5358233044185376`*^9, 3.53582333451099*^9}, {3.535823374915062*^9, 
   3.5358235131157045`*^9}, {3.5358235856090317`*^9, 3.5358236244219*^9}, {
   3.535823671143982*^9, 3.5358236829064026`*^9}, {3.5358237600797377`*^9, 
   3.535823791919394*^9}, {3.535823830810262*^9, 3.535823834351468*^9}, {
   3.535823891807369*^9, 3.5358239053637934`*^9}, {3.5358239420706577`*^9, 
   3.5358239633490953`*^9}, 3.535863647709474*^9, 3.535867745488166*^9, {
   3.535870455408924*^9, 3.535870473645012*^9}, {3.536173856347906*^9, 
   3.536173963457694*^9}, {3.536174014454184*^9, 3.536174027729807*^9}, {
   3.5361746053218217`*^9, 3.5361746149314384`*^9}, {3.5361749406132107`*^9, 
   3.5361749546688356`*^9}, {3.537099203659336*^9, 3.537099204123344*^9}, {
   3.537099273283682*^9, 3.5370992965788307`*^9}, 3.5371001026471033`*^9, {
   3.5371002063851147`*^9, 3.537100208309923*^9}, {3.537100238826915*^9, 
   3.5371004036702833`*^9}, {3.537100455360618*^9, 3.537100530540921*^9}, {
   3.537100577355506*^9, 3.53710059160116*^9}, {3.537109198461097*^9, 
   3.537109236618764*^9}, {3.537111875319599*^9, 3.537111966766959*^9}, {
   3.544510085142268*^9, 3.544510086491521*^9}, {3.544511135130258*^9, 
   3.544511149122176*^9}, {3.544511265775567*^9, 3.5445112663694477`*^9}, {
   3.544511306595739*^9, 3.544511450576692*^9}, {3.54451148203868*^9, 
   3.544511513829035*^9}, {3.544511554825622*^9, 3.544511571921101*^9}, {
   3.544589325870937*^9, 3.5445893449341707`*^9}, {3.545669873420969*^9, 
   3.5456699152446423`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Examples", "Section",
 CellChangeTimes->{{3.528082835016738*^9, 3.528082852421329*^9}, {
  3.5361740437510357`*^9, 3.5361740476198425`*^9}}],

Cell["\<\
Tensor syntax: a[{i,j,k,...}] where a, i, j, k, ... can be arbitrary symbols. 

Index symbols should avoid \[OpenCurlyQuote]ii\[CloseCurlyQuote] and \
\[OpenCurlyQuote]jj\[CloseCurlyQuote] (used in internal loops) and indices \
defined in \[OpenCurlyQuote]sidx\[CloseCurlyQuote] above.

Tensor symbols should avoid \[OpenCurlyQuote]\[Delta]\[CloseCurlyQuote], \
which is used for the Kronecker tensor.

Summation indices can be arbitrary symbols, but will be replaced by indices \
defined in \[OpenCurlyQuote]sidx\[CloseCurlyQuote] in standardized expressions.

\[OpenCurlyQuote]Einstein\[CloseCurlyQuote] can currently only be used on \
expanded sums of simple products without brackets, see examples below.

\[OpenCurlyQuote]DeltaTensor\[CloseCurlyQuote] evaluates really slow for \
degree > 8.
\
\>", "Text",
 CellChangeTimes->{{3.5361743602443914`*^9, 3.5361743683564053`*^9}, {
  3.536174465918977*^9, 3.5361745835909834`*^9}, {3.5361746685331326`*^9, 
  3.5361747293888397`*^9}, {3.5361748198689985`*^9, 3.536174932735197*^9}, {
  3.5361750147757406`*^9, 3.5361750964106846`*^9}, {3.5361782095853524`*^9, 
  3.5361782517834263`*^9}},
 FontFamily->"Courier New",
 FontSize->14,
 FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "l"}], "}"}], "]"}], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"a", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "j"}], "}"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.537099247405488*^9, 3.537099254673469*^9}, {
  3.537100619355412*^9, 3.5371006438639402`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"a", "[", 
   RowBox[{"{", 
    RowBox[{"j", ",", "l"}], "}"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.537099255209606*^9, 3.5371006469662533`*^9, {3.5444598905889416`*^9, 
   3.544459910759777*^9}, 3.5444631720889053`*^9, 3.5445101468966017`*^9, 
   3.544510225659878*^9, 3.544511050239092*^9, 3.544515781179469*^9, {
   3.5504701032770243`*^9, 3.550470115499988*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{
   RowBox[{"2", 
    SuperscriptBox["b", "2"], " ", 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], 
    RowBox[{"a", "[", 
     RowBox[{"{", "i", "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"k", ",", "j"}], "}"}], "]"}], 
    RowBox[{"a", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}], "-", 
   RowBox[{"4", 
    RowBox[{"b", "[", 
     RowBox[{"{", "j", "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}], "]"}], 
    RowBox[{"a", "[", 
     RowBox[{"{", "k", "}"}], "]"}]}], "-", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"b", "[", 
     RowBox[{"{", "p", "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j", ",", "k"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"m", ",", "n"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"l", ",", "j"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"p", ",", "q"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i3", ",", "i2"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i3"}], "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "k"}], "}"}], "]"}], 
    RowBox[{"a", "[", 
     RowBox[{"{", "m", "}"}], "]"}], 
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"n", ",", "l"}], "}"}], "]"}], 
    RowBox[{"c", "[", 
     RowBox[{"{", 
      RowBox[{"q", ",", "i"}], "}"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521532417028535*^9, 3.5215324824706497`*^9}, {
   3.5215325899392385`*^9, 3.521532605336466*^9}, {3.521532651028946*^9, 
   3.521532667720976*^9}, {3.521533076348093*^9, 3.5215330771124945`*^9}, 
   3.521533294077676*^9, {3.5215338480502486`*^9, 3.5215338641806765`*^9}, {
   3.5215344376844845`*^9, 3.521534443440894*^9}, {3.5215347405746164`*^9, 
   3.521534770791869*^9}, {3.521563584774993*^9, 3.521563585086993*^9}, {
   3.521600543894824*^9, 3.5216005447528257`*^9}, {3.5216015799081984`*^9, 
   3.5216015815462008`*^9}, {3.5216039687403936`*^9, 
   3.5216039690055943`*^9}, {3.521616640094588*^9, 3.5216166471458*^9}, {
   3.5216236611100955`*^9, 3.521623699002562*^9}, {3.5216240319071465`*^9, 
   3.5216240322971478`*^9}, {3.521624590232127*^9, 3.521624606409356*^9}, {
   3.5216247433463964`*^9, 3.521624744110798*^9}, {3.5216248285849457`*^9, 
   3.5216248540597906`*^9}, {3.5221355796026874`*^9, 
   3.5221356040323305`*^9}, {3.535891205097562*^9, 3.5358912380173607`*^9}, {
   3.5361740528926516`*^9, 3.536174053095452*^9}, {3.5361741079295483`*^9, 
   3.536174112874757*^9}, 3.5361746202978477`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", 
     RowBox[{"{", "s0", "}"}], "]"}], "2"]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"a", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"{", "s0", "}"}], "]"}]}], "-", 
  RowBox[{"3", " ", "\[Alpha]", " ", 
   RowBox[{"a", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"{", "s1", "}"}], "]"}], " ", 
   RowBox[{"c", "[", 
    RowBox[{"{", 
     RowBox[{"s0", ",", "s1"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.529768540741559*^9, 3.529819863465331*^9, 3.5356818103955326`*^9, 
   3.5358240618944683`*^9, {3.5358679222995234`*^9, 3.5358679520746517`*^9}, 
   3.535868614435717*^9, 3.535868709728489*^9, 3.5358804954628773`*^9, 
   3.535890328808488*^9, 3.535891162042852*^9, {3.535891209959179*^9, 
   3.535891239170025*^9}, 3.5360780953983355`*^9, 3.5360781404356146`*^9, 
   3.536078190074902*^9, 3.536078263488631*^9, 3.536174074529889*^9, 
   3.5361741134207573`*^9, 3.5370980588047047`*^9, 3.537100657545164*^9, {
   3.544459890651342*^9, 3.544459910822177*^9}, 3.5444631721513057`*^9, 
   3.544510146958226*^9, 3.544510225720625*^9, 3.54451105028441*^9, 
   3.544515781215599*^9, {3.550470103589683*^9, 3.550470115564684*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{
   FractionBox["3", 
    RowBox[{"4", 
     SqrtBox["a"]}]], 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "j1"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "k1"}], "}"}], "]"}], " ", 
   RowBox[{"\[Lambda]1", "[", 
    RowBox[{"{", "j1", "}"}], "]"}], " ", 
   RowBox[{"\[Lambda]1", "[", 
    RowBox[{"{", "k1", "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5217027060381317`*^9, 3.5217027068493333`*^9}, {
   3.5217027707002454`*^9, 3.5217027723382483`*^9}, 3.5217032322426558`*^9, {
   3.521704631939514*^9, 3.5217046331407166`*^9}, {3.5221356115359435`*^9, 
   3.52213561527995*^9}, {3.535905273318959*^9, 3.535905317638637*^9}, 
   3.5359054225332212`*^9, {3.5359058614877925`*^9, 3.535905861706193*^9}, {
   3.536174118007166*^9, 3.536174122562374*^9}, 3.536174622981053*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   RowBox[{"\[Lambda]1", "[", 
    RowBox[{"{", "i1", "}"}], "]"}], " ", 
   RowBox[{"\[Lambda]1", "[", 
    RowBox[{"{", "i2", "}"}], "]"}]}], 
  RowBox[{"4", " ", 
   SqrtBox["a"]}]]], "Output",
 CellChangeTimes->{
  3.5297685409911594`*^9, 3.529819864198532*^9, 3.535824064640073*^9, 
   3.535867962804055*^9, 3.535868621062838*^9, 3.535868712527179*^9, 
   3.5358804992276373`*^9, 3.535890331903932*^9, 3.535891247571021*^9, {
   3.535905270386154*^9, 3.5359053183874383`*^9}, 3.5359054230636225`*^9, 
   3.535905783378455*^9, {3.5359058574473853`*^9, 3.535905875481017*^9}, 
   3.536078096911538*^9, 3.536078268231039*^9, 3.536174123420375*^9, 
   3.537100660163393*^9, {3.5444598907137423`*^9, 3.5444599108845773`*^9}, 
   3.5444631722293053`*^9, 3.544510146992399*^9, 3.5445102257545424`*^9, 
   3.544511050319598*^9, 3.5445157812480164`*^9, {3.5504701036267033`*^9, 
   3.550470115579234*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{
   SuperscriptBox["h", "4"], " ", 
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"0", ",", "1"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"j1", ",", "k1"}], "}"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"\[Delta]", "[", 
     RowBox[{"{", 
      RowBox[{"j2", ",", "k2"}], "}"}], "]"}], "2"], " ", 
   RowBox[{"\[Lambda]3", "[", 
    RowBox[{"{", "j1", "}"}], "]"}], " ", 
   RowBox[{"\[Lambda]3", "[", 
    RowBox[{"{", "k1", "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.521706621567009*^9, 3.521706624921015*^9}, {
   3.536174196210103*^9, 3.53617420001651*^9}, 3.536174236520574*^9, 
   3.536174624899856*^9}],

Cell[BoxData[
 RowBox[{"3", " ", 
  SuperscriptBox["h", "4"], " ", 
  RowBox[{"\[Alpha]", "[", 
   RowBox[{"0", ",", "1"}], "]"}], " ", 
  RowBox[{"\[Delta]", "[", 
   RowBox[{"{", 
    RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
  SuperscriptBox[
   RowBox[{"\[Lambda]3", "[", 
    RowBox[{"{", "s0", "}"}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.5297685410691595`*^9, 3.529819864323333*^9, 3.5358240688208804`*^9, 
   3.5358679693194723`*^9, 3.535868716912401*^9, 3.5358805007818747`*^9, 
   3.5358903341511*^9, 3.53589124912154*^9, 3.5360780983467407`*^9, 
   3.5360782729890475`*^9, 3.536174200484511*^9, 3.5361742374565754`*^9, 
   3.537100663242467*^9, {3.544459890776142*^9, 3.5444599109469776`*^9}, 
   3.544463172307306*^9, 3.544510147026019*^9, 3.544510225788734*^9, 
   3.5445110503530607`*^9, 3.54451578128174*^9, {3.550470103659259*^9, 
   3.5504701156142063`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], "]"}], 
    RowBox[{"DeltaTensor", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.537098087747464*^9, 3.537098127648642*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["2", "3"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"k", ",", "l"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"s0", ",", "s0"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"k", ",", "l"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.537098089152878*^9, 3.537098128156918*^9}, 
   3.537100676985342*^9, {3.544459890822942*^9, 3.5444599110093775`*^9}, 
   3.544463172369706*^9, 3.5445101470632772`*^9, 3.544510225826241*^9, 
   3.544511050385028*^9, 3.544515781315117*^9, {3.550470103691925*^9, 
   3.550470115647946*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"m", ",", "n", ",", "k", ",", "l"}], "}"}], "]"}], 
    RowBox[{"DeltaTensor", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n"}], "}"}], 
     "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.5361742594838142`*^9, 3.53617462703706*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["4", "5"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "s0", ",", "s0"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "5"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"s0", ",", "s0", ",", "s1", ",", "s1"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5358241258233805`*^9, 3.535867982645041*^9, 3.535868720355925*^9, 
   3.535880666396079*^9, 3.535890343483696*^9, 3.535890422460313*^9, 
   3.5358912576573563`*^9, 3.5360782798374596`*^9, 3.536174262167019*^9, {
   3.5444598909477425`*^9, 3.5444599111029778`*^9}, 3.5444631724789057`*^9, 
   3.544510147097074*^9, 3.54451022586406*^9, 3.544511050418511*^9, 
   3.54451578134827*^9, {3.550470103726203*^9, 3.550470115679702*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"B", "[", 
     RowBox[{"{", 
      RowBox[{"m", ",", "n", ",", "k"}], "}"}], "]"}], 
    RowBox[{"DeltaTensor", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l", ",", "m", ",", "n"}], "}"}], 
     "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.530983002663172*^9, 3.530983056857667*^9}, {
   3.530983121894181*^9, 3.530983169833065*^9}, {3.5358239720851107`*^9, 
   3.535823989323141*^9}, {3.5358241053093443`*^9, 3.535824135854198*^9}, {
   3.535867992920478*^9, 3.535867994839965*^9}, 3.5361742667378273`*^9, 
   3.5361746296734643`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["2", "5"], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "l"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "5"], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", 
     RowBox[{"l", ",", "s0", ",", "s0"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "5"], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", 
     RowBox[{"j", ",", "s0", ",", "s0"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "l"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "5"], " ", 
   RowBox[{"B", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "s0", ",", "s0"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"j", ",", "l"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.5309830105723853`*^9, 3.5309830151743937`*^9}, {
   3.530983051647258*^9, 3.5309830576376677`*^9}, 3.5309831716894684`*^9, 
   3.5358239899471416`*^9, {3.535824081488103*^9, 3.535824136759*^9}, 
   3.535867995826621*^9, 3.535868721724359*^9, 3.535890306356326*^9, 
   3.535890346112424*^9, 3.5358912675882607`*^9, 3.536078280835861*^9, 
   3.5361742672526283`*^9, {3.544459891072542*^9, 3.544459911212178*^9}, 
   3.544463172588106*^9, 3.544510147131132*^9, 3.544510225907053*^9, 
   3.5445110504568853`*^9, 3.544515781382052*^9, {3.550470103759225*^9, 
   3.550470115718075*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Einstein", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", 
      RowBox[{"m", ",", "l", ",", "k"}], "}"}], "]"}], 
    RowBox[{"DeltaTensor", "[", 
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "]"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.530983002663172*^9, 3.530983056857667*^9}, {
   3.530983121894181*^9, 3.530983169833065*^9}, {3.5358239720851107`*^9, 
   3.535823989323141*^9}, {3.5358241053093443`*^9, 3.535824135854198*^9}, {
   3.535867992920478*^9, 3.535867994839965*^9}, {3.535868729210937*^9, 
   3.53586873758972*^9}, {3.5361742704506335`*^9, 3.5361743023838897`*^9}, 
   3.536174632263069*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["2", "3"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "m"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"m", ",", "s0", ",", "s0"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.5309830105723853`*^9, 3.5309830151743937`*^9}, {
   3.530983051647258*^9, 3.5309830576376677`*^9}, 3.5309831716894684`*^9, 
   3.5358239899471416`*^9, {3.535824081488103*^9, 3.535824136759*^9}, 
   3.535867995826621*^9, {3.535868721724359*^9, 3.535868738437314*^9}, 
   3.535890349155717*^9, 3.535891269645749*^9, 3.5360782814442625`*^9, {
   3.536174271027835*^9, 3.5361743027894907`*^9}, {3.5444598911349425`*^9, 
   3.544459911258978*^9}, 3.5444631726349063`*^9, 3.54451014715891*^9, 
   3.5445102259608383`*^9, 3.5445110504847717`*^9, 3.544515781415473*^9, {
   3.550470103792294*^9, 3.550470115747642*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sym", "[", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2"}], "}"}], "]"}], 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.544589370081414*^9, 3.544589382935837*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i4"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i3"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i4"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.544589383450638*^9, {3.55047010382623*^9, 3.550470115780195*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sym", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"{", "i1", "}"}], "]"}], 
    RowBox[{"DeltaTensor", "[", 
     RowBox[{"{", 
      RowBox[{"i2", ",", "i3", ",", "i4", ",", "i5"}], "}"}], "]"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.544589370081414*^9, 3.5445894463343487`*^9}, {
  3.544589480295608*^9, 3.544589492416829*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i5", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i4", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i3"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i5", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i3", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i4"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i4", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i3", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i5"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i5", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i2", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i5"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i1", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i5"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i4"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i4", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i2", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i4"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i1", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i4"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "i5"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i3", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i2"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i2", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "i3"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "15"], " ", 
   RowBox[{"A", "[", 
    RowBox[{"{", "i1", "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "i3"}], "}"}], "]"}], " ", 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"{", 
     RowBox[{"i4", ",", "i5"}], "}"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.544589383450638*^9, 3.54458944714555*^9}, {
  3.5445894817932105`*^9, 3.5445894928692303`*^9}, {3.550470103874154*^9, 
  3.550470115830667*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1649, 898},
WindowMargins->{{10, Automatic}, {Automatic, 8}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.1999999999999, 841.98},
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{42.661417785, 42.661417785}, {57.82677227999999, \
57.82677227999999}}},
FrontEndVersion->"10.4 for Linux x86 (64-bit) (April 11, 2016)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 456, 10, 77, "Text"],
Cell[CellGroupData[{
Cell[1039, 34, 128, 1, 67, "Section"],
Cell[1170, 37, 26193, 665, 1744, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27400, 707, 151, 2, 70, "Section"],
Cell[27554, 711, 1223, 27, 70, "Text"],
Cell[CellGroupData[{
Cell[28802, 742, 590, 18, 70, "Input"],
Cell[29395, 762, 418, 9, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29850, 776, 2920, 73, 70, "Input"],
Cell[32773, 851, 1341, 30, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34151, 886, 917, 21, 70, "Input"],
Cell[35071, 909, 950, 19, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36058, 933, 806, 22, 70, "Input"],
Cell[36867, 957, 892, 19, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37796, 981, 378, 11, 70, "Input"],
Cell[38177, 994, 709, 19, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38923, 1018, 420, 11, 70, "Input"],
Cell[39346, 1031, 896, 21, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40279, 1057, 663, 15, 70, "Input"],
Cell[40945, 1074, 1510, 39, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42492, 1118, 713, 16, 70, "Input"],
Cell[43208, 1136, 1053, 23, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44298, 1164, 311, 9, 70, "Input"],
Cell[44612, 1175, 1536, 51, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46185, 1231, 402, 11, 70, "Input"],
Cell[46590, 1244, 4832, 154, 70, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

